<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>HomeDaemon</name>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="55"/>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="57"/>
        <source>Show main window</source>
        <translation>Mostrar a xanela principal</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="72"/>
        <source>Communication</source>
        <translation>Comunicación</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="75"/>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="315"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
</context>
</TS>